@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11326 2019-01-08 18:50:45Z Lavender $
+# $Id: views.py 11336 2019-01-15 06:39:03Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-01-09 02:50:45 +0800 (??, 09 ?? 2019) $
-# $Revision: 11326 $ 
+# $Date: 2019-01-15 15:39:03 +0900 (週二, 15 一月 2019) $
+# $Revision: 11336 $ 
 
 import json
 import logging
@@ -925,9 +925,11 @@ class ECPayServerReplyView(generic.View):
             request, *args, **kwargs)
 
     def get(self, request, *args, **kwargs):
+        logger.warn("GET: %s" % (request.GET))
         return render("|ErrorMessage")
 
     def post(self, request, *args, **kwargs):
+        logger.warn("POST: %s" % (request.POST))
         # data 
         try:
             self.tradeNo = request.POST.get('AllPayLogisticsID')
